declare type RangeTuple = readonly [min: number, max: number];
export interface NumericRangeOptions {
    min?: number;
    max?: number;
    precision?: number;
    step?: number;
    value?: string | number;
}
declare type MinMaxOptions = {
    min?: number;
    max?: number;
};
/**
 * Class to manage the lower and upper boundary of a target value
 */
export declare class NumericRange {
    private options;
    /**
     * The mininum value of the range
     */
    min: number;
    /**
     * The maximum value of the range
     */
    max: number;
    /**
     * The precision or decimal count of the range's value
     */
    precision: number | undefined;
    /**
     * The step value of the range
     */
    step: number;
    /**
     * The precision of the range's step
     */
    private stepPrecision;
    /**
     * The `value` of the range
     */
    value: string | number;
    /**
     * Initializes a new instance of the NumericRange class
     */
    constructor(options: NumericRangeOptions);
    /**
     * Creates a range based on the specified `[min, max]` tuple
     */
    static fromTuple: (tuple: RangeTuple) => NumericRange;
    /**
     * Creates a range from the specified min and max (passed as arguments)
     */
    static create: (min: number, max: number, value?: string | number | undefined) => NumericRange;
    /**
     * Creates an array of the ranges from array of values
     */
    static fromValues: (values: number[], options?: MinMaxOptions) => NumericRange[];
    /**
     * Creates a numeric range from a percent value
     */
    static fromPercent: (percent: number, options?: MinMaxOptions) => NumericRange;
    /**
     * Creates a new numeric range with the same values
     */
    clone: () => NumericRange;
    /**
     * Creates a new range instance with new options
     */
    withOptions: (options: Partial<NumericRangeOptions>) => NumericRange;
    /**
     * Converts the range value to number
     */
    valueOf: () => number;
    /**
     * Returns the range value as string (rounded to the maximum precision)
     */
    toString: () => string;
    /**
     * Returns the JSON representation of the range
     */
    toJSON: () => {
        min: number;
        max: number;
        value: string | number;
    };
    /**
     * Converts numeric range to iterable to support `for..of` loop,
     * spread operator, and `Array.from(...)`
     */
    [Symbol.iterator](): Generator<number, void, unknown>;
    /**
     * Whether the `value` is within the `min` and `max`
     */
    get isInRange(): boolean;
    /**
     * Whether the `value` is at `min`
     */
    get isAtMin(): boolean;
    /**
     * Whether the `value` is at `max`
     */
    get isAtMax(): boolean;
    /**
     * Get the decimal count of the range's value
     */
    private get computedPrecision();
    /**
     * Converts a string value to a number and strips letters
     */
    static parse: (value: string | number) => number;
    /**
     * Returns a transformed value given the input and output range tuples
     */
    static transform: (inputTuple: RangeTuple, outputTuple: RangeTuple) => (value: number) => number;
    /**
     * Set the value based on specified percent
     */
    setValueFromPercent: (percent: number) => this;
    /**
     * Sets the `value` of the range
     */
    setValue: (value: string | number) => this;
    /**
     * Sets the step value of the range
     */
    setStep: (step: number) => this;
    /**
     * Sets the value to the minimum value of the range
     */
    setToMin: () => this;
    /**
     * Sets the value to the maximum value of the range
     */
    setToMax: () => this;
    /**
     * Converts the value to a percentage value between the `min` and `max`
     */
    toPercent: () => number;
    /**
     * Ensures the value is within the range
     */
    clamp: () => this;
    toPrecision: () => this;
    /**
     * Increments the range's value by the specified step
     */
    increment: (step?: number) => this;
    /**
     * Decrements the range's value by the specified step
     */
    decrement: (step?: number) => this;
    /**
     * Rounds the value to the nearest step
     */
    snapToStep: () => this;
    /**
     * Resets the range values to the initial
     */
    reset: () => this;
}
export {};
